@@ -289,7 +289,7 @@
     </message>
     <message>
         <source>invalid SQL or failed DB connection:</source>
-        <translation>Neplatné SQL nebo nepodařilo připojit k DB:</translation>
+        <translation type="obsolete">Neplatné SQL nebo nepodařilo připojit k DB:</translation>
     </message>
     <message>
         <source>Music Summary</source>
@@ -379,6 +379,26 @@
         <source>Sound Panel Fifth and Later Play Output</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>invalid SQL or failed DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">Vše</translation>
+    </message>
+    <message>
+        <source>Relative</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NaturalLog Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -768,6 +788,52 @@ ze &amp;souboru</translation>
         <source>Importing</source>
         <translation>Zavádí se</translation>
     </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEdit</name>
+    <message>
+        <source>&amp;Audition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Pause</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Stop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Konec</translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEditDialog</name>
+    <message>
+        <source>Set Cue Point</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Zrušit</translation>
+    </message>
 </context>
 <context>
     <name>RDCutDialog</name>
@@ -1828,6 +1894,13 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
         <translation type="obsolete">Tracker</translation>
     </message>
 </context>
+<context>
+    <name>RDPanelButton</name>
+    <message>
+        <source>No Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDPasswd</name>
     <message>
