@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdnownext.h,v 1.1.2.1 2008-11-25 22:15:49 fredg Exp $
+//      $Id: rdnownext.h,v 1.3.8.1 2013/10/16 21:14:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,8 +24,9 @@
 #define RDNOWNEXT_H
 
 #include <rdlog_line.h>
+#include "../rlm/rlm.h"
 
-void RDResolveNowNext(QString *str,RDLogLine **loglines);
+void RDResolveNowNext(QString *str,RDLogLine **loglines,int encoding);
 
 
 #endif  // RDNOWNEXT_H
