@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsvc.h,v 1.22.2.2 2008/12/08 19:00:23 fredg Exp $
+//      $Id: rdsvc.h,v 1.26.8.2 2013/10/11 22:00:52 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,10 +42,14 @@ class RDSvc : public QObject
   bool exists() const;
   QString description() const;
   void setDescription(const QString &desc) const;
+  QString programCode() const;
+  void setProgramCode(const QString &str) const;
   QString nameTemplate() const;
   void setNameTemplate(const QString &str) const;
   QString trackGroup() const;
   void setTrackGroup(const QString &group) const;
+  QString autospotGroup() const;
+  void setAutospotGroup(const QString &group) const;
   bool autoRefresh() const;
   void setAutoRefresh(bool state);
   int defaultLogShelflife() const;
@@ -54,6 +58,8 @@ class RDSvc : public QObject
   void setElrShelflife(int days) const;
   bool chainto() const;
   void setChainto(bool state) const;
+  QString importTemplate(ImportSource src) const;
+  void setImportTemplate(ImportSource src,const QString &str) const;
   QString breakString() const;
   void setBreakString(const QString &str);
   QString trackString(ImportSource src) const;
@@ -64,6 +70,9 @@ class RDSvc : public QObject
   void setTrackCart(ImportSource src,const QString &str);
   QString importPath(ImportSource src,ImportOs os) const;
   void setImportPath(ImportSource src,ImportOs os,const QString &path) const;
+  QString preimportCommand(ImportSource src,ImportOs os) const;
+  void setPreimportCommand(ImportSource src,ImportOs os,
+			   const QString &path) const;
   int importOffset(ImportSource src,ImportField field) const;
   void setImportOffset(ImportSource src,ImportField field,int offset) const;
   int importLength(ImportSource src,ImportField field) const;
@@ -80,6 +89,7 @@ class RDSvc : public QObject
 		     const QString &logname);
   void create(const QString exemplar) const;
   void remove() const;
+  QString xml() const;
   static QString timeString(int hour,int secs);
 
  signals:
