@@ -2,9 +2,9 @@
 //
 // Edit a Rivendell Workstation Configuration
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_station.cpp,v 1.48.2.1 2008-11-30 00:32:59 fredg Exp $
+//      $Id: edit_station.cpp,v 1.57.4.9 2013/12/23 18:47:23 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,6 +42,7 @@
 #include <edit_rdairplay.h>
 #include <edit_rdpanel.h>
 #include <edit_rdlogedit.h>
+#include <edit_cartslots.h>
 #include <edit_decks.h>
 #include <edit_audios.h>
 #include <edit_ttys.h>
@@ -51,9 +52,10 @@
 #include <view_adapters.h>
 #include <list_dropboxes.h>
 #include <list_encoders.h>
+#include <edit_jack.h>
 #include <globals.h>
 
-EditStation::EditStation(QString display,QWidget *parent,const char *name)
+EditStation::EditStation(QString sname,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   RDSqlQuery *q;
@@ -77,9 +79,11 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  station_station=new RDStation(display);
+  station_station=new RDStation(sname);
+  station_cae_station=NULL;
+  caeStationActivatedData(station_station->caeStation());
 
-  setCaption(tr("Host: ")+display);
+  setCaption(tr("Host: ")+sname);
 
   GetPrivateProfileString(RD_CONF_FILE,"Identity","Password",temp,"",255);
   station_catch_connect=new RDCatchConnect(0,this,"station_catch_connect");
@@ -208,15 +212,28 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   select_button->setGeometry(180,157,50,22);
   connect(select_button,SIGNAL(clicked()),this,SLOT(selectClicked()));
 
+  //
+  // Cue Output
+  //
+  station_cue_sel=new RDCardSelector(this);
+  station_cue_sel->setGeometry(100,179,120,117);
+  QLabel *station_cue_sel_label=new QLabel(station_cue_sel,
+					   tr("Cue &Output:"),this);
+  station_cue_sel_label->setGeometry(10,179,100,19);
+  station_cue_sel_label->setFont(font);
+  station_cue_sel_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Heartbeat Checkbox
   //
   station_heartbeat_box=new QCheckBox(this,"station_heartbeat_box");
-  station_heartbeat_box->setGeometry(10,182,15,15);
+  //  station_heartbeat_box->setGeometry(10,182,15,15);
+  station_heartbeat_box->setGeometry(10,226,15,15);
   QLabel *label=new QLabel(station_heartbeat_box,
 			   tr("Enable Heartbeat"),this,
 			   "station_heartbeat_label");
-  label->setGeometry(30,180,150,20);
+  label->setGeometry(30,224,150,20);
+  //  label->setGeometry(30,180,150,20);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   connect(station_heartbeat_box,SIGNAL(toggled(bool)),
@@ -226,11 +243,11 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Filter Checkbox
   //
   station_filter_box=new QCheckBox(this,"station_filter_box");
-  station_filter_box->setGeometry(210,182,15,15);
+  station_filter_box->setGeometry(210,226,15,15);
   label=new QLabel(station_filter_box,
 		   tr("Use Realtime Filtering"),this,
 		   "station_filter_label");
-  label->setGeometry(230,180,150,20);
+  label->setGeometry(230,226,150,20);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -238,16 +255,16 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Heartbeat Cart
   //
   station_hbcart_edit=new QLineEdit(this,"station_hbcart_edit");
-  station_hbcart_edit->setGeometry(65,204,60,19);
+  station_hbcart_edit->setGeometry(65,248,60,19);
   station_hbcart_edit->setReadOnly(true);
   station_hbcart_label=new QLabel(station_hbcart_edit,
 				  tr("Cart:"),this,
 				  "station_hbcart_label");
-  station_hbcart_label->setGeometry(10,204,50,19);
+  station_hbcart_label->setGeometry(10,248,50,19);
   station_hbcart_label->setFont(font);
   station_hbcart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   station_hbcart_button=new QPushButton(this,"station_hbcart_button");
-  station_hbcart_button->setGeometry(140,201,60,26);
+  station_hbcart_button->setGeometry(140,245,60,26);
   station_hbcart_button->setFont(font);
   station_hbcart_button->setText(tr("Select"));
   connect(station_hbcart_button,SIGNAL(clicked()),
@@ -257,17 +274,17 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Heartbeat Interval
   //
   station_hbinterval_spin=new QSpinBox(this,"station_hbinterval_spin");
-  station_hbinterval_spin->setGeometry(275,204,45,19);
+  station_hbinterval_spin->setGeometry(275,248,45,19);
   station_hbinterval_spin->setRange(1,300);
   station_hbinterval_label=new QLabel(station_hbinterval_spin,
 				  tr("Interval:"),this,
 				  "station_hbinterval_label");
-  station_hbinterval_label->setGeometry(220,204,50,19);
+  station_hbinterval_label->setGeometry(220,248,50,19);
   station_hbinterval_label->setFont(font);
   station_hbinterval_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   station_hbinterval_unit=new QLabel(tr("secs"),
 				     this,"station_hbinterval_unit");
-  station_hbinterval_unit->setGeometry(325,204,100,19);
+  station_hbinterval_unit->setGeometry(325,248,100,19);
   station_hbinterval_unit->setFont(font);
   station_hbinterval_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -275,18 +292,54 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // System Maintenance Checkbox
   //
   station_maint_box=new QCheckBox(this,"station_maint_box");
-  station_maint_box->setGeometry(10,231,15,15);
+  station_maint_box->setGeometry(10,275,15,15);
   label=new QLabel(station_maint_box,tr("Include in System Maintenance Pool"),
 		   this,"station_maint_label");
-  label->setGeometry(30,229,sizeHint().width()-40,20);
+  label->setGeometry(30,273,sizeHint().width()-40,20);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
+  //
+  // System Services Section
+  //
+  label=new QLabel(tr("System Services"),this);
+  label->setGeometry(30,291,110,20);
+  label->setFont(font);
+  label->setAlignment(AlignCenter|ShowPrefix);
+
+  //
+  // HTTP Service Host
+  //
+  station_http_station_box=new QComboBox(this,"station_http_station_box");
+  station_http_station_box->setGeometry(145,312,200,19);
+  station_http_station_box->setEditable(false);
+  QLabel *station_http_station_label=new QLabel(station_http_station_box,
+					   tr("HTTP Xport:"),this,
+					   "station_http_station_label");
+  station_http_station_label->setGeometry(11,312,130,19);
+  station_http_station_label->setFont(font);
+  station_http_station_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
+  //
+  // CAE Service Host
+  //
+  station_cae_station_box=new QComboBox(this,"station_cae_station_box");
+  station_cae_station_box->setGeometry(145,333,200,19);
+  station_cae_station_box->setEditable(false);
+  connect(station_cae_station_box,SIGNAL(activated(const QString &)),
+	  this,SLOT(caeStationActivatedData(const QString &)));
+  QLabel *station_cae_station_label=new QLabel(station_cae_station_box,
+					   tr("Core Audio Engine:"),this,
+					   "station_cae_station_label");
+  station_cae_station_label->setGeometry(11,333,130,19);
+  station_cae_station_label->setFont(font);
+  station_cae_station_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   //  RDLibrary Configuration Button
   //
   QPushButton *button=new QPushButton(this,"library_button");
-  button->setGeometry(10,259,80,50);
+  button->setGeometry(10,371,80,50);
   button->setFont(font);
   button->setText(tr("RD&Library"));
   connect(button,SIGNAL(clicked()),this,SLOT(editLibraryData()));
@@ -295,7 +348,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDCatch Configuration Button
   //
   button=new QPushButton(this,"tty_button");
-  button->setGeometry(100,259,80,50);
+  button->setGeometry(100,371,80,50);
   button->setFont(font);
   button->setText(tr("RDCatch"));
   connect(button,SIGNAL(clicked()),this,SLOT(editDeckData()));
@@ -304,7 +357,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDAirPlay Configuration Button
   //
   button=new QPushButton(this,"airplay_button");
-  button->setGeometry(190,259,80,50);
+  button->setGeometry(190,371,80,50);
   button->setFont(font);
   button->setText(tr("RDAirPlay"));
   connect(button,SIGNAL(clicked()),this,SLOT(editAirPlayData()));
@@ -313,7 +366,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDPanel Configuration Button
   //
   button=new QPushButton(this,"rdpanel_button");
-  button->setGeometry(280,259,80,50);
+  button->setGeometry(280,371,80,50);
   button->setFont(font);
   button->setText(tr("RDPanel"));
   connect(button,SIGNAL(clicked()),this,SLOT(editPanelData()));
@@ -322,16 +375,25 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDLogEdit Configuration Button
   //
   button=new QPushButton(this,"logedit_button");
-  button->setGeometry(10,319,80,50);
+  button->setGeometry(10,431,80,50);
   button->setFont(font);
   button->setText(tr("RDLogEdit"));
   connect(button,SIGNAL(clicked()),this,SLOT(editLogEditData()));
 
+  //
+  //  RDCartSlots Configuration Button
+  //
+  button=new QPushButton(this);
+  button->setGeometry(100,431,80,50);
+  button->setFont(font);
+  button->setText(tr("RDCart\nSlots"));
+  connect(button,SIGNAL(clicked()),this,SLOT(editCartSlotsData()));
+
   //
   // Dropboxes Configuration Button
   //
   button=new QPushButton(this,"dropboxes_button");
-  button->setGeometry(100,319,80,50);
+  button->setGeometry(190,431,80,50);
   button->setFont(font);
   button->setText(tr("Dropboxes"));
   connect(button,SIGNAL(clicked()),this,SLOT(editDropboxesData()));
@@ -340,7 +402,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  Switcher Configuration Button
   //
   button=new QPushButton(this,"switcher_button");
-  button->setGeometry(190,319,80,50);
+  button->setGeometry(280,431,80,50);
   button->setFont(font);
   button->setText(tr("Switchers\nGPIO"));
   connect(button,SIGNAL(clicked()),this,SLOT(editSwitcherData()));
@@ -349,7 +411,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  Host Variables Configuration Button
   //
   button=new QPushButton(this,"hostvars_button");
-  button->setGeometry(280,319,80,50);
+  button->setGeometry(10,491,80,50);
   button->setFont(font);
   button->setText(tr("Host\nVariables"));
   connect(button,SIGNAL(clicked()),this,SLOT(editHostvarsData()));
@@ -358,7 +420,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  Audio Ports Configuration Button
   //
   button=new QPushButton(this,"audio_ports_button");
-  button->setGeometry(10,379,80,50);
+  button->setGeometry(100,491,80,50);
   button->setFont(font);
   button->setText(tr("Audio\nPorts"));
   connect(button,SIGNAL(clicked()),this,SLOT(editAudioData()));
@@ -367,7 +429,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  TTY Configuration Button
   //
   button=new QPushButton(this,"tty_button");
-  button->setGeometry(100,379,80,50);
+  button->setGeometry(190,491,80,50);
   button->setFont(font);
   button->setText(tr("Serial\nPorts"));
   connect(button,SIGNAL(clicked()),this,SLOT(editTtyData()));
@@ -376,7 +438,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  View Adapters (Audio Resources) Configuration Button
   //
   button=new QPushButton(this,"view_adapters_button");
-  button->setGeometry(190,379,80,50);
+  button->setGeometry(280,491,80,50);
   button->setFont(font);
   button->setText(tr("Audio\nResources"));
   connect(button,SIGNAL(clicked()),this,SLOT(viewAdaptersData()));
@@ -385,16 +447,25 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Encoders Configuration Button
   //
   button=new QPushButton(this,"encoders_button");
-  button->setGeometry(280,379,80,50);
+  button->setGeometry(55,551,80,50);
   button->setFont(font);
   button->setText(tr("Custom\nEncoders"));
   connect(button,SIGNAL(clicked()),this,SLOT(editEncodersData()));
 
+  //
+  // JACK Settings Button
+  //
+  button=new QPushButton(this,"backup_button");
+  button->setGeometry(145,551,80,50);
+  button->setFont(font);
+  button->setText(tr("JACK\nSettings"));
+  connect(button,SIGNAL(clicked()),this,SLOT(jackSettingsData()));
+
   //
   // Backups Configuration Button
   //
   button=new QPushButton(this,"backup_button");
-  button->setGeometry(145,439,80,50);
+  button->setGeometry(235,551,80,50);
   button->setFont(font);
   button->setText(tr("Backups"));
   connect(button,SIGNAL(clicked()),this,SLOT(editBackupsData()));
@@ -431,6 +502,23 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   if(cartnum>0) {
     station_startup_cart_edit->setText(QString().sprintf("%06u",cartnum));
   }
+
+
+  if(station_station->scanned()) {
+    station_cue_sel->setMaxCards(station_station->cards());
+    for(int i=0;i<station_cue_sel->maxCards();i++) {
+      station_cue_sel->setMaxPorts(i,station_station->cardInputs(i));
+    }
+  }
+  else {
+    QMessageBox::information(this,tr("RDAdmin - No Audio Configuration Data"),
+			     tr("Channel assignments will not be available for this host as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on the host\nconfigured to run the CAE service in order to populate the audio resources database."));
+    station_cue_sel->setDisabled(true);
+    station_cue_sel->setDisabled(true);
+  }
+  station_cue_sel->setCard(station_station->cueCard());
+  station_cue_sel->setPort(station_station->cuePort());
+
   sql="select LOGIN_NAME from USERS";
   q=new RDSqlQuery(sql);
   while(q->next()) {
@@ -440,6 +528,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
     }
     item++;
   }
+  delete q;
   station_broadcast_sec_edit->
     setCurrentItem((RDStation::BroadcastSecurityMode)station_station->
                      broadcastSecurity());
@@ -464,12 +553,43 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
       break;
   }
   station_maint_box->setChecked(station_station->systemMaint());
+
+  station_http_station_box->insertItem("localhost");
+  station_http_station_box->insertItem(RD_RDSELECT_LABEL);
+  station_cae_station_box->insertItem("localhost");
+  station_cae_station_box->insertItem(RD_RDSELECT_LABEL);
+  sql=QString().sprintf("select NAME from STATIONS \
+                         where NAME!=\"%s\" order by NAME",
+			(const char *)RDEscapeString(sname));
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    station_http_station_box->insertItem(q->value(0).toString());
+    if(q->value(0).toString()==station_station->httpStation()) {
+      station_http_station_box->
+	setCurrentItem(station_http_station_box->count()-1);
+    }
+    station_cae_station_box->insertItem(q->value(0).toString());
+    if(q->value(0).toString()==station_station->caeStation()) {
+      station_cae_station_box->
+	setCurrentItem(station_cae_station_box->count()-1);
+    }
+  }
   delete q;
+  for(int i=0;i<station_http_station_box->count();i++) {
+    if(station_http_station_box->text(i)==station_station->httpStation()) {
+      station_http_station_box->setCurrentItem(i);
+    }
+    if(station_cae_station_box->text(i)==station_station->caeStation()) {
+      station_cae_station_box->setCurrentItem(i);
+    }
+  }
 }
 
 
 EditStation::~EditStation()
 {
+  delete station_station;
+  delete station_cae_station;
 }
 
 
@@ -477,7 +597,8 @@ void EditStation::selectClicked()
 {
   int cartnum;
 
-  if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0)==0) {
+  if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
+			     admin_user->name(),admin_user->password())==0) {
     station_startup_cart_edit->setText(QString().sprintf("%06d",cartnum));
   }
 }
@@ -498,15 +619,30 @@ void EditStation::heartbeatClickedData()
 {
   int cartnum;
 
-  if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0)==0) {
+  if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
+			     admin_user->name(),admin_user->password())==0) {
     station_hbcart_edit->setText(QString().sprintf("%06d",cartnum));
   }
 }
 
 
+void EditStation::caeStationActivatedData(const QString &station_name)
+{
+  if(station_cae_station!=NULL) {
+    delete station_cae_station;
+  }
+  if(station_name=="localhost") {
+    station_cae_station=new RDStation(station_station->name());
+  }
+  else {
+    station_cae_station=new RDStation(station_name);
+  }
+}
+
+
 QSize EditStation::sizeHint() const
 {
-  return QSize(375,569);
+  return QSize(375,681);
 } 
 
 
@@ -516,6 +652,25 @@ QSizePolicy EditStation::sizePolicy() const
 }
 
 
+void EditStation::paintEvent(QPaintEvent *e)
+{
+  QPainter *p=new QPainter(this);
+  p->setPen(black);
+  p->setBrush(black);
+
+  //
+  // System Services
+  //
+  p->moveTo(10,301);
+  p->lineTo(sizeHint().width()-20,301);
+  p->lineTo(sizeHint().width()-20,359);
+  p->lineTo(10,359);
+  p->lineTo(10,301);
+
+  delete p;
+}
+
+
 void EditStation::okData()
 {
   QHostAddress addr;
@@ -557,6 +712,8 @@ void EditStation::okData()
     station_station->setHeartbeatCart(0);
     station_station->setHeartbeatInterval(0);
   }
+  station_station->setCueCard(station_cue_sel->card());
+  station_station->setCuePort(station_cue_sel->port());
   station_station->setDescription(station_description_edit->text());
   station_station->setDefaultName(station_default_name_edit->currentText());
   station_station->
@@ -580,6 +737,8 @@ void EditStation::okData()
     station_station->setFilterMode(RDStation::FilterAsynchronous);
   }
   station_station->setSystemMaint(station_maint_box->isChecked());
+  station_station->setHttpStation(station_http_station_box->currentText());
+  station_station->setCaeStation(station_cae_station_box->currentText());
   station_catch_connect->reloadHeartbeat();
   station_catch_connect->reloadOffset();
 
@@ -606,7 +765,8 @@ void EditStation::cancelData()
 
 void EditStation::editLibraryData()
 {
-  EditRDLibrary *edit_conf=new EditRDLibrary(station_station,0);
+  EditRDLibrary *edit_conf=
+    new EditRDLibrary(station_station,station_cae_station);
   edit_conf->exec();
   delete edit_conf;
 }
@@ -614,7 +774,7 @@ void EditStation::editLibraryData()
 
 void EditStation::editDeckData()
 {
-  EditDecks *edit_conf=new EditDecks(station_station,this);
+  EditDecks *edit_conf=new EditDecks(station_station,station_cae_station,this);
   if(edit_conf->exec()==0) {
     station_catch_connect->reload();
   }
@@ -624,7 +784,8 @@ void EditStation::editDeckData()
 
 void EditStation::editAirPlayData()
 {
-  EditRDAirPlay *edit_conf=new EditRDAirPlay(station_station,0);
+  EditRDAirPlay *edit_conf=
+    new EditRDAirPlay(station_station,station_cae_station);
   edit_conf->exec();
   delete edit_conf;
 }
@@ -632,7 +793,8 @@ void EditStation::editAirPlayData()
 
 void EditStation::editPanelData()
 {
-  EditRDPanel *edit_conf=new EditRDPanel(station_station,0);
+  EditRDPanel *edit_conf=
+    new EditRDPanel(station_station,station_cae_station,this);
   edit_conf->exec();
   delete edit_conf;
 }
@@ -640,7 +802,17 @@ void EditStation::editPanelData()
 
 void EditStation::editLogEditData()
 {
-  EditRDLogedit *edit_conf=new EditRDLogedit(station_station);
+  EditRDLogedit *edit_conf=
+    new EditRDLogedit(station_station,station_cae_station);
+  edit_conf->exec();
+  delete edit_conf;
+}
+
+
+void EditStation::editCartSlotsData()
+{
+  EditCartSlots *edit_conf=
+    new EditCartSlots(station_station,station_cae_station,this);
   edit_conf->exec();
   delete edit_conf;
 }
@@ -685,7 +857,6 @@ void EditStation::editHostvarsData()
   delete list_conf;
 }
 
-
 void EditStation::editBackupsData()
 {
   EditBackup *edit_backup=new EditBackup(station_station,this);
@@ -711,6 +882,14 @@ void EditStation::editEncodersData()
 }
 
 
+void EditStation::jackSettingsData()
+{
+  EditJack *d=new EditJack(station_station,this);
+  d->exec();
+  delete d;
+}
+
+
 QString EditStation::DisplayPart(QString string)
 {
   for(unsigned i=0;i<string.length();i++) {
