@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_upload.cpp,v 1.15.2.2 2008-11-19 16:49:55 fredg Exp $
+//      $Id: edit_upload.cpp,v 1.22 2011/06/21 18:31:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -241,19 +241,30 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   edit_normalize_spin->setRange(-30,0);
   edit_normalize_label=new QLabel(edit_normalize_spin,tr("Level:"),
 				 this,"normalize_spin_label");
-  edit_normalize_label->setGeometry(215,208,45,20);
+  edit_normalize_label->setGeometry(215,206,45,20);
   edit_normalize_label->setFont(label_font);
   edit_normalize_label->setAlignment(AlignRight|AlignVCenter);
   edit_normalize_unit=new QLabel(tr("dBFS"),this,"normalize_unit_label");
-  edit_normalize_unit->setGeometry(310,208,40,20);
+  edit_normalize_unit->setGeometry(310,206,40,20);
   edit_normalize_unit->setFont(label_font);
   edit_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
 
+  //
+  // Export Metadata Box
+  //
+  edit_metadata_box=new QCheckBox(this,"edit_metadata_box");
+  edit_metadata_box->setGeometry(115,231,15,15);
+  label=new QLabel(edit_metadata_box,tr("Export Library Metadata"),
+		   this,"metadata_check_label");
+  label->setGeometry(135,231,160,20);
+  label->setFont(label_font);
+  label->setAlignment(AlignLeft|AlignVCenter);
+
   //
   // Button Label
   //
   label=new QLabel(tr("Active Days"),this,"active_days_label");
-  label->setGeometry(47,236,90,19);
+  label->setGeometry(47,263,90,19);
   label->setFont(label_font);
   label->setAlignment(AlignHCenter|ShowPrefix);
 
@@ -261,10 +272,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Monday Button
   //
   edit_mon_button=new QCheckBox(this,"edit_mon_button");
-  edit_mon_button->setGeometry(20,255,20,20);
+  edit_mon_button->setGeometry(20,282,20,20);
   label=new QLabel(edit_mon_button,
 		   tr("Monday"),this,"edit_mon_label");
-  label->setGeometry(40,255,115,20);
+  label->setGeometry(40,282,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -272,10 +283,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Tuesday Button
   //
   edit_tue_button=new QCheckBox(this,"edit_tue_button");
-  edit_tue_button->setGeometry(115,255,20,20);
+  edit_tue_button->setGeometry(115,282,20,20);
   label=new QLabel(edit_tue_button,
 		   tr("Tuesday"),this,"edit_tue_label");
-  label->setGeometry(135,255,115,20);
+  label->setGeometry(135,282,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -283,10 +294,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Wednesday Button
   //
   edit_wed_button=new QCheckBox(this,"edit_wed_button");
-  edit_wed_button->setGeometry(215,255,20,20);
+  edit_wed_button->setGeometry(215,282,20,20);
   label=new QLabel(edit_wed_button,
 		   tr("Wednesday"),this,"edit_wed_label");
-  label->setGeometry(235,255,115,20);
+  label->setGeometry(235,282,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -294,10 +305,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Thursday Button
   //
   edit_thu_button=new QCheckBox(this,"edit_thu_button");
-  edit_thu_button->setGeometry(335,255,20,20);
+  edit_thu_button->setGeometry(335,282,20,20);
   label=new QLabel(edit_thu_button,
 		   tr("Thursday"),this,"edit_thu_label");
-  label->setGeometry(355,255,115,20);
+  label->setGeometry(355,282,115,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -305,10 +316,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Friday Button
   //
   edit_fri_button=new QCheckBox(this,"edit_fri_button");
-  edit_fri_button->setGeometry(440,255,20,20);
+  edit_fri_button->setGeometry(440,282,20,20);
   label=new QLabel(edit_fri_button,
 		   tr("Friday"),this,"edit_fri_label");
-  label->setGeometry(460,255,40,20);
+  label->setGeometry(460,282,40,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -316,10 +327,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Saturday Button
   //
   edit_sat_button=new QCheckBox(this,"edit_sat_button");
-  edit_sat_button->setGeometry(130,280,20,20);
+  edit_sat_button->setGeometry(130,307,20,20);
   label=new QLabel(edit_sat_button,
 		   tr("Saturday"),this,"edit_sat_label");
-  label->setGeometry(150,280,60,20);
+  label->setGeometry(150,307,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -327,10 +338,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Sunday Button
   //
   edit_sun_button=new QCheckBox(this,"edit_sun_button");
-  edit_sun_button->setGeometry(300,280,20,20);
+  edit_sun_button->setGeometry(300,307,20,20);
   label=new QLabel(edit_sun_button,
 		   tr("Sunday"),this,"edit_sun_label");
-  label->setGeometry(320,280,60,20);
+  label->setGeometry(320,307,60,20);
   label->setFont(day_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -338,10 +349,10 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // OneShot Button
   //
   edit_oneshot_box=new QCheckBox(this,"edit_oneshot_box");
-  edit_oneshot_box->setGeometry(20,315,15,15);
+  edit_oneshot_box->setGeometry(20,342,15,15);
   label=new QLabel(edit_oneshot_box,
 		   tr("Make OneShot"),this,"edit_oneshot_label");
-  label->setGeometry(40,313,115,20);
+  label->setGeometry(40,343,115,20);
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -349,16 +360,16 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   // Event Offset
   //
   edit_eventoffset_spin=new QSpinBox(this,"edit_eventoffset_spin");
-  edit_eventoffset_spin->setGeometry(245,313,45,20);
+  edit_eventoffset_spin->setGeometry(245,340,45,20);
   edit_eventoffset_spin->setRange(-30,30);
   label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),
 		   this,"edit_eventoffset_label");
-  label->setGeometry(140,313,100,20);
+  label->setGeometry(140,340,100,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignRight);
   label=new QLabel(edit_eventoffset_spin,tr("days"),
 		   this,"edit_eventoffset_unit");
-  label->setGeometry(295,308,40,20);
+  label->setGeometry(295,335,40,20);
   label->setFont(label_font);
   label->setAlignment(AlignVCenter|AlignLeft);
 
@@ -413,6 +424,7 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   if(!edit_recording->cutName().isEmpty()) {
     edit_destination_edit->setText("Cut "+edit_recording->cutName());
   }
+  edit_metadata_box->setChecked(edit_recording->enableMetadata());
   edit_mon_button->setChecked(edit_recording->mon());
   edit_tue_button->setChecked(edit_recording->tue());
   edit_wed_button->setChecked(edit_recording->wed());
@@ -424,7 +436,7 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   edit_oneshot_box->setChecked(edit_recording->oneShot());
   edit_settings.setFormat(edit_recording->format());
   edit_settings.setChannels(edit_recording->channels());
-  edit_settings.setSampleRate(edit_recording->samprate());
+  edit_settings.setSampleRate(edit_recording->sampleRate());
   edit_settings.setBitRate(edit_recording->bitrate());
   edit_settings.setQuality(edit_recording->quality());
   edit_format_edit->setText(edit_settings.description());
@@ -460,7 +472,7 @@ EditUpload::~EditUpload()
 
 QSize EditUpload::sizeHint() const
 {
-  return QSize(520,414);
+  return QSize(520,441);
 } 
 
 
@@ -482,8 +494,8 @@ void EditUpload::stationChangedData(const QString &str)
 void EditUpload::urlChangedData(const QString &str)
 {
   QUrl url(str);
-  QString protocol=url.protocol();
-  if((protocol=="ftp")||(protocol=="smb")) {
+  QString protocol=url.protocol().lower();
+  if((protocol=="ftp")||(protocol=="file")) {
     edit_username_label->setEnabled(true);
     edit_username_edit->setEnabled(true);
     edit_password_label->setEnabled(true);
@@ -502,7 +514,8 @@ void EditUpload::selectCartData()
 {
   QString str;
 
-  RDCutDialog *cut=new RDCutDialog(&edit_cutname,rdstation_conf,edit_filter);
+  RDCutDialog *cut=new RDCutDialog(&edit_cutname,rdstation_conf,catch_system,
+				   edit_filter);
   switch(cut->exec()) {
       case 0:
 	edit_description_edit->setText(RDCutPath(edit_cutname));
@@ -564,14 +577,14 @@ void EditUpload::okData()
   }
   RDUrl url(edit_url_edit->text());
   QString protocol=url.protocol();
-  if((protocol!="ftp")&&(protocol!="smb")&&(protocol!="file")) {
+  if((protocol!="ftp")&&(protocol!="file")) {
     QMessageBox::warning(this,
 			 tr("Invalid URL"),tr("Unsupported URL protocol!"));
     return;
   }
-  if((protocol=="smb")&&((!url.validSmbShare())||(url.smbPath()=="/"))) {
-    QMessageBox::warning(this,
-			 tr("Invalid URL"),tr("The URL is invalid!"));
+  if((protocol=="file")&&(edit_username_edit->text().isEmpty())) {
+    QMessageBox::warning(this,tr("Missing Username"),
+			 tr("You must specify a username!"));
     return;
   }
   if(!CheckEvent(false)) {
@@ -594,7 +607,7 @@ void EditUpload::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
   p->setPen(QColor(black));
-  p->drawRect(10,244,sizeHint().width()-20,62);
+  p->drawRect(10,271,sizeHint().width()-20,62);
   p->end();
 }
 
@@ -628,6 +641,7 @@ bool EditUpload::CheckFormat()
   switch(edit_settings.format()) {
       case RDSettings::Pcm16:
       case RDSettings::MpegL2:
+      case RDSettings::MpegL2Wav:
 	res=true;
 	break;
 
@@ -684,6 +698,7 @@ void EditUpload::Save()
   edit_recording->setUrl(edit_url_edit->text());
   edit_recording->setUrlUsername(edit_username_edit->text());
   edit_recording->setUrlPassword(edit_password_edit->text());
+  edit_recording->setEnableMetadata(edit_metadata_box->isChecked());
   edit_recording->setMon(edit_mon_button->isChecked());
   edit_recording->setTue(edit_tue_button->isChecked());
   edit_recording->setWed(edit_wed_button->isChecked());
@@ -695,7 +710,7 @@ void EditUpload::Save()
   edit_recording->setOneShot(edit_oneshot_box->isChecked());
   edit_recording->setFormat(edit_settings.format());
   edit_recording->setChannels(edit_settings.channels());
-  edit_recording->setSamprate(edit_settings.sampleRate());
+  edit_recording->setSampleRate(edit_settings.sampleRate());
   edit_recording->setBitrate(edit_settings.bitRate());
   edit_recording->setQuality(edit_settings.quality());
   if(edit_normalize_box->isChecked()) {
