@@ -120,7 +120,7 @@ editieren</translation>
     <message>
         <source>This cut is used in one or more RDCatch events!
 Do you still want to delete it?</source>
-        <translation>Dieser Cut wird in einem oder mehreren RDCatch-Events
+        <translation type="obsolete">Dieser Cut wird in einem oder mehreren RDCatch-Events
 verwendet! Trotzdem löschen?</translation>
     </message>
     <message>
@@ -173,12 +173,53 @@ Trotzdem fortfahren?</translation>
     </message>
     <message>
         <source>Unable to delete audio!</source>
-        <translation>Kann die Audiodatei(en) nicht löschen!</translation>
+        <translation type="obsolete">Kann die Audiodatei(en) nicht löschen!</translation>
     </message>
     <message>
         <source>No audio is present in the cut!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more cuts are used in one or more RDCatch events!
+Do you still want to delete?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete audio for cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No data copied - you must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -332,6 +373,14 @@ abbrechen</translation>
         <source>Rip Track</source>
         <translation>Titel rippen</translation>
     </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[none]</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -712,6 +761,30 @@ Notes</source>
         <translation>Notizen
 &amp;editieren</translation>
     </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cond&amp;uctor:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Song &amp;ID:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Beats per Minute:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
@@ -811,10 +884,6 @@ Notes</source>
         <source>Cut Report</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cart Data Dump</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Type:</source>
         <translation type="unfinished">Typ:</translation>
@@ -831,6 +900,18 @@ Notes</source>
         <source>ALL</source>
         <translation type="unfinished">ALLE</translation>
     </message>
+    <message>
+        <source>Cart Data Dump (fixed width)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Data Dump (CSV)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prepend Field Names</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -975,7 +1056,7 @@ starten</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
-        <translation>ABSPIELREIHENFOLGE</translation>
+        <translation type="obsolete">ABSPIELREIHENFOLGE</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
@@ -1057,11 +1138,11 @@ verwendet. Trotzdem löschen?</translation>
     </message>
     <message>
         <source>Sequence</source>
-        <translation>Sequenz</translation>
+        <translation type="obsolete">Sequenz</translation>
     </message>
     <message>
         <source>Random</source>
-        <translation>Zufall</translation>
+        <translation type="obsolete">Zufall</translation>
     </message>
     <message>
         <source>TFN</source>
@@ -1103,6 +1184,22 @@ verwendet. Trotzdem löschen?</translation>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PUBLISHER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow Cart Dragging</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RecordCut</name>
