@@ -701,11 +701,11 @@ Gruppe des ausgewählten Service!</translation>
     <name>MainWidget</name>
     <message>
         <source>RDLogEdit - Host</source>
-        <translation>RDLogEdit - Host</translation>
+        <translation type="obsolete">RDLogEdit - Host</translation>
     </message>
     <message>
         <source>User: [Unknown]</source>
-        <translation>Benutzer: [Unbekannt]</translation>
+        <translation type="obsolete">Benutzer: [Unbekannt]</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
@@ -846,6 +846,14 @@ Fortfahren?</translation>
 See your system administrator for an update!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VoiceTracker</name>
@@ -1058,5 +1066,13 @@ therefore only existing transitions will be editable.</source>
         <source>Save segue changes?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLogEdit - Voice Tracker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
