@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport.cpp,v 1.34 2011/12/28 21:09:46 cvs Exp $
+//      $Id: rdimport.cpp,v 1.34.4.8 2013/12/11 19:38:00 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -76,6 +76,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   import_delete_source=false;
   import_delete_cuts=false;
   import_drop_box=false;
+  import_set_user_defined="";
   import_stdin_specified=false;
   import_startdate_offset=0;
   import_enddate_offset=0;
@@ -158,6 +159,9 @@ MainObject::MainObject(QObject *parent,const char *name)
 	import_delete_source=true;
       }
     }
+    if(import_cmd->key(i)=="--set-user-defined") {
+      import_set_user_defined=import_cmd->value(i);
+    }
     if(import_cmd->key(i)=="--metadata-pattern") {
       import_metadata_pattern=import_cmd->value(i);
       if(!VerifyPattern(import_metadata_pattern)) {
@@ -405,6 +409,10 @@ MainObject::MainObject(QObject *parent,const char *name)
     else {
       printf(" DropBox mode is OFF\n");
     }
+    if(!import_set_user_defined.isEmpty()) {
+      printf(" Setting the User Defined field to \"%s\"\n",
+	     (const char *)import_set_user_defined);
+    }
     if(!import_metadata_pattern.isEmpty()) {
       printf(" Using metadata pattern: %s\n",
 	     (const char *)import_metadata_pattern);
@@ -775,8 +783,13 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   }
   int cutnum=
     cart->addCut(import_format,import_bitrate,import_channels);
+  if(cutnum<0) {
+    fprintf(stderr,"rdimport: no free cuts available in cart %06u\n",*cartnum);
+    delete cart;
+    return MainObject::NoCut;
+  }
   RDCut *cut=new RDCut(QString().sprintf("%06u_%03d",*cartnum,cutnum));
-  RDAudioImport *conv=new RDAudioImport(import_station,this);
+  RDAudioImport *conv=new RDAudioImport(import_station,import_config,this);
   conv->setCartNumber(cart->number());
   conv->setCutNumber(cutnum);
   conv->setSourceFile(wavefile->getName());
@@ -795,7 +808,6 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   settings->setAutotrimLevel(import_autotrim_level/100);
   conv->setDestinationSettings(settings);
   conv->setUseMetadata(cart_created);
-
   if(import_verbose) {
     PrintLogDateTime();
     if(wavedata->title().length()==0 || ( (wavedata->title().length()>0) && (wavedata->title()[0] == '\0')) ) {
@@ -825,10 +837,10 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 	    (const char *)filename.utf8());
     fflush(stderr);
     if(cart_created) {
-      cart->remove(import_station,import_user);
+      cart->remove(import_station,import_user,import_config);
     }
     else {
-      cart->removeCut(import_station,import_user,cut->cutName());
+      cart->removeCut(import_station,import_user,cut->cutName(),import_config);
     }
     delete cut;
     delete cart;
@@ -878,6 +890,9 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
       cart->setTitle(wavedata->cutId());
     }
   }
+  if(!import_metadata_pattern.isEmpty()) {
+    cart->setTitle(wavedata->title());
+  }
   if(import_startdate_offset!=0) {
     dt=cut->startDatetime(&ok);
     if(ok) {
@@ -890,7 +905,7 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
       cut->setEndDatetime(dt.addDays(import_enddate_offset),true);
     }
   }
-  if (import_create_dates)  {
+  if(import_create_dates)  {
     dt=cut->startDatetime(&ok);
     if (!ok){
       dt=QDateTime(QDate::currentDate(), QTime(0,0,0));
@@ -902,6 +917,10 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
       cut->setEndDatetime(dt.addDays(import_create_enddate_offset),true);
     }
   }
+  cut->setOriginName(import_station->name());
+  if(!import_set_user_defined.isEmpty()) {
+    cart->setUserDefined(import_set_user_defined);
+  }
   delete settings;
   delete conv;
   delete cut;
@@ -973,6 +992,7 @@ void MainObject::VerifyFile(const QString &filename,unsigned *cartnum)
 	      break;
 	      
 	    case MainObject::NoCart:
+	    case MainObject::NoCut:
 	      (*ci)->pass=0;
 	      (*ci)->checked=true;
 	      break;
@@ -1091,7 +1111,7 @@ bool MainObject::IsWav(int fd)
 }
 
 
-bool MainObject::FindChunk(int fd,char *chunk_name,bool *fix_needed)
+bool MainObject::FindChunk(int fd,const char *chunk_name,bool *fix_needed)
 {
   int i;
   char name[5]={0,0,0,0,0};
@@ -1264,6 +1284,16 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
 	    wavedata->setMetadataFound(true);
 	    break;
 
+	  case 'r':
+	    wavedata->setConductor(value);
+	    wavedata->setMetadataFound(true);
+	    break;
+
+	  case 's':
+	    wavedata->setTmciSongId(value);
+	    wavedata->setMetadataFound(true);
+	    break;
+
 	  case 't':
 	    wavedata->setTitle(value);
 	    wavedata->setMetadataFound(true);
@@ -1337,6 +1367,8 @@ bool MainObject::VerifyPattern(const QString &pattern)
 	case 'm':
 	case 'n':
 	case 'p':
+	case 'r':
+	case 's':
 	case 't':
 	case 'u':
 	case '%':
@@ -1373,7 +1405,7 @@ void MainObject::DeleteCuts(unsigned cartnum)
   }
   unsigned dev;
   RDCart *cart=new RDCart(cartnum);
-  cart->removeAllCuts(import_station,import_user);
+  cart->removeAllCuts(import_station,import_user,import_config);
   cart->updateLength();
   cart->resetRotation();
   cart->calculateAverageLength(&dev);
